
# THIS FILE IS GENERATED FROM PYRAD_PROC SETUP.PY
short_version = '1.4.5'
version = '1.4.5'
full_version = '1.4.5'
git_revision = 'c55316b67a2072cbaa02ba367b42b68f153a081d'
compile_date_time = '2022-08-19 11:27'
username = 'wolfensb'
release = True

if not release:
    version = full_version
